import { Gateway } from './Gateway';
import { AccessToken } from '../entities/AccessToken';
import { AuthenticatedUser } from '../entities/AuthenticatedUser';
import { Comment } from '../entities/Comment';
import { Item } from '../entities/Item';
import { Like } from '../entities/Like';
import { Project } from '../entities/Project';
import { Reaction } from '../entities/Reaction';
import { Tag } from '../entities/Tag';
import { Tagging } from '../entities/Tagging';
import { Team } from '../entities/Team';
import { TeamInvitation } from '../entities/TeamInvitation';
import { Template } from '../entities/Template';
import { User } from '../entities/User';
export declare class Qiita extends Gateway {
    /**
     * Qiita APIのページネーションをラップする非同期反復可能オブジェクトを返します
     * nextの引数に文字列 'reset' を渡すと最初のインデックスに戻ることができます。
     * @param url リクエストするURL
     * @param params リクエストのオプション
     */
    paginationGenerator<T extends any[]>(url: string, params?: any): AsyncIterableIterator<T>;
    /**
     * 与えられた認証情報をもとに新しいアクセストークンを発行します。
     * @param clientId 登録されたAPIクライアントを特定するためのID
     * @param clientSecret 登録されたAPIクライアントを認証するための秘密鍵
     * @param code リダイレクト用のURLに付与された、アクセストークンと交換するための文字列
     * @return アクセストークン
     */
    fetchAccessToken: (clientId: string, clientSecret: string, code: string) => Promise<AccessToken>;
    /**
     * 指定されたアクセストークンを失効させ、それ以降利用できないようにします。
     * @param token アクセストークン
     * @return 空のオブジェクト
     */
    deleteAccessToken: (token: string) => Promise<void>;
    /**
     * コメントを取得します。
     * @param commentId コメントのID
     * @return コメントのエンティティを返します
     */
    fetchComment: (commentId: string) => Promise<Comment>;
    /**
     * コメントを更新します。
     * @param commentId コメントのID
     * @param body コメントの内容を表すMarkdown形式の文字列
     */
    updateComment: (commentId: string, body: string) => Promise<Comment>;
    /**
     * コメントを削除します。
     * @param commentId コメントのID
     * @return 空のオブジェクト
     */
    deleteComment: (commentId: string) => Promise<void>;
    /**
     * コメントに付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param commentId コメントID
     * @return 絵文字リアクション
     */
    fetchCommentReactions: (commentId: string) => Promise<Reaction[]>;
    /**
     * コメントに絵文字リアクションを付けます。
     * @param commentId コメントID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createCommentReaction: (commentId: string, name: string) => Promise<Reaction>;
    /**
     * コメントから絵文字リアクションを削除します。
     * @param commentId コメントID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteCommentReaction: (commentId: string, name: string) => Promise<Reaction>;
    /**
     * タグ一覧を作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @param sort 並び順 (countで投稿数順、nameで名前順)
     * @return タグ一覧を返す非同期反復可能オブジェクト
     */
    fetchTags: (page: string, perPage: string, sort: string) => AsyncIterableIterator<Tag[]>;
    /**
     * タグを取得します。
     * @param tagId タグのID
     * @return タグ
     */
    fetchTag: (tagId: string) => Promise<Tag>;
    /**
     * タグをフォローしているかどうかを調べます。
     * @param tagId タグのID
     * @return タグ
     */
    checkIfFollowingTag: (tagId: string) => Promise<Tag>;
    /**
     * タグをフォローします。
     * @param tagId タグのID
     * @return 空のオブジェクト
     */
    followTag: (tagId: string) => Promise<Tag>;
    /**
     * タグをフォローします。
     * @param tagId タグのID
     * @return 空のオブジェクト
     */
    unfollowTag: (tagId: string) => Promise<void>;
    /**
     * 指定されたタグが付けられた投稿一覧を、タグを付けた日時の降順で返します。
     * @param tagId タグID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchTaggedItems: (tagId: string, page: string, perPage: string) => AsyncIterableIterator<Item[]>;
    /**
     * チーム内のテンプレート一覧を返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return テンプレート一覧を返す非同期反復可能オブジェクト
     */
    fetchTemplates: (page: string, perPage: string) => AsyncIterableIterator<Template[]>;
    /**
     * テンプレートを取得します。
     * @param tempalteId テンプレートID
     * @return テンプレート
     */
    fetchTempalte: (templateId: string) => Promise<Template>;
    /**
     * 新しくテンプレートを作成します。
     * @param body テンプレートの本文
     * @param name テンプレートを判別するための名前
     * @param tags タグ一覧
     * @param title 生成される投稿のタイトルの雛形
     * @return テンプレート
     */
    createTemplate: (body: string, name: string, tags: Tagging[], title: string) => Promise<Template>;
    /**
     * テンプレートを更新します。
     * @param body テンプレートの本文
     * @param name テンプレートを判別するための名前
     * @param tags タグ一覧
     * @param title 生成される投稿のタイトルの雛形
     * @return テンプレート
     */
    updateTempalte: (body: string, name: string, tags: Tagging[], title: string) => Promise<Template>;
    /**
     * テンプレートを削除します。
     * @param templateId テンプレートID
     * @return 空のオブジェクト
     */
    deleteTemplate: (templateId: string) => Promise<void>;
    /**
     * チーム内に存在するプロジェクト一覧をプロジェクト作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return プロジェクト一覧
     */
    fetchProjects: (page: string, perPage: string) => AsyncIterableIterator<Project[]>;
    /**
     * プロジェクトを返します。
     * @param projectId プロジェクトID
     * @return プロジェクト
     */
    fetchProject: (projectId: string) => Promise<Project>;
    /**
     * プロジェクトを新たに作成します。
     * @param archived このプロジェクトが進行中かどうか
     * @param body Markdown形式の本文
     * @param name プロジェクト名
     * @param tags 投稿に付いたタグ一覧
     * @return プロジェクト
     */
    createProject: (archived: boolean, body: string, name: string, tags: Tagging[]) => Promise<Project>;
    /**
     * プロジェクトを更新します。
     * @param archived このプロジェクトが進行中かどうか
     * @param body Markdown形式の本文
     * @param name プロジェクト名
     * @param tags 投稿に付いたタグ一覧
     * @return プロジェクト
     */
    updateProject: (archived: boolean, body: string, name: string, tags: Tagging[]) => Promise<Project>;
    /**
     * プロジェクトを削除します。
     * @param projectId プロジェクトID
     * @return 空のオブジェクト
     */
    deleteProject: (projectId: string) => Promise<void>;
    /**
     * プロジェクトに付けられたコメント一覧を投稿日時の降順で取得します。
     * @param projectId プロジェクトのID
     * @return コメント一覧
     */
    fetchProjectComments: (projectId: string) => Promise<Comment[]>;
    /**
     * プロジェクトに対してコメントを投稿します。
     * @param projectId 投稿のID
     * @param body コメントの内容を表すMarkdown形式の文字列
     * @return 投稿したコメント
     */
    createProjectComment: (projectId: string, body: string) => Promise<Comment[]>;
    /**
     * プロジェクトに付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param projectId プロジェクトID
     * @return 絵文字リアクション一覧
     */
    fetchProjectReactions: (projectId: string) => Promise<Reaction[]>;
    /**
     * プロジェクトに絵文字リアクションを付けます。
     * @param projectId プロジェクトID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createProjectReaction: (projectId: string, name: string) => Promise<Reaction>;
    /**
     * プロジェクトから絵文字リアクションを削除します。
     * @param projectId プロジェクトID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteProjectReaction: (projectId: string, name: string) => Promise<Reaction>;
    /**
     * 全てのユーザの一覧を作成日時の降順で取得します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchUsers: (page: string, perPage: string) => AsyncIterableIterator<User[]>;
    /**
     * ユーザを取得します。
     * @param userId ユーザーID
     * @return ユーザー
     */
    fetchUser: (userId: string) => Promise<User>;
    /**
     * ユーザがフォローしているユーザ一覧を取得します。
     * @param userId ユーザーID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchUserFollowees: (userId: string, page: string, perPage: string) => AsyncIterableIterator<User[]>;
    /**
     * ユーザをフォローしているユーザ一覧を取得します。
     * @param userId ユーザーID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchUserFollowers: (userId: string, page: string, perPage: string) => AsyncIterableIterator<User[]>;
    /**
     * 指定されたユーザの投稿一覧を、作成日時の降順で返します。
     * @param userId ユーザID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchUserItems: (userId: string, page: string, perPage: string) => AsyncIterableIterator<Item[]>;
    /**
     * 指定されたユーザがストックした投稿一覧を、ストックした日時の降順で返します。
     * @param userId ユーザID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchUserStocks: (userId: string, page: string, perPage: string) => AsyncIterableIterator<Item[]>;
    /**
     * ユーザがフォローしているタグ一覧をフォロー日時の降順で返します。
     * @param userId ユーザーID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return タグ一覧を返す非同期反復可能オブジェクト
     */
    fetchUserFollowingTags: (userId: string, page: string, perPage: string) => AsyncIterableIterator<Tag[]>;
    /**
     * ユーザをフォローしている場合に204を返します。
     * @param userId ユーザーID
     * @return 空のオブジェクト
     */
    checkIfFollowingUser: (userId: string) => Promise<void>;
    /**
     * ユーザをフォローします
     * @param userId ユーザーID
     * @return 空のオブジェクト
     */
    followUser: (userId: string) => Promise<void>;
    /**
     * ユーザへのフォローを外します。
     * @param userId ユーザーID
     * @return 空のオブジェクト
     */
    unfollowUser: (userId: string) => Promise<void>;
    /**
     * 投稿の一覧を作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @param query 検索クエリ
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchItems: (page: string, perPage: string, query: string) => AsyncIterableIterator<Item[]>;
    /**
     * 投稿を取得します。
     * @param itemId 投稿ID
     * @return 投稿
     */
    fetchItem: (itemId: string) => Promise<Item>;
    /**
     * 新たに投稿を作成します。
     * @param params.body Markdown形式の本文
     * @param params.coediting この投稿が共同更新状態かどうか (Qiita:Teamでのみ有効)
     * @param params.gist 本文中のコードをGistに投稿するかどうか (GitHub連携を有効化している場合のみ有効)
     * @param params.groupUrlName この投稿を公開するグループの url_name (null で全体に公開。Qiita:Teamでのみ有効)
     * @param params.private 限定共有状態かどうかを表すフラグ (Qiita:Teamでは無効)
     * @param params.tag 投稿に付いたタグ一覧
     * @param params.title 投稿のタイトル
     * @param params.tweet Twitterに投稿するかどうか (Twitter連携を有効化している場合のみ有効)
     * @return 投稿
     */
    createItem: (params: {
        body: string;
        coediting: boolean;
        gist: boolean;
        groupUrlName?: string | null | undefined;
        private: boolean;
        tags: Tagging;
        title: string;
        tweet: boolean;
    }) => Promise<Item>;
    /**
     * 投稿を更新します。
     * @param itemId 投稿のID
     * @param params.coediting この投稿が共同更新状態かどうか (Qiita:Teamでのみ有効)
     * @param params.groupUrlName この投稿を公開するグループの url_name (null で全体に公開。Qiita:Teamでのみ有効)
     * @param params.private 限定共有状態かどうかを表すフラグ (Qiita:Teamでは無効)
     * @param params.tag 投稿に付いたタグ一覧
     * @param params.title 投稿のタイトル
     * @return 投稿
     */
    updateItem: (itemId: string, params: {
        body: string;
        coediting: boolean;
        groupUrlName?: string | null | undefined;
        private: boolean;
        tags: Tagging;
        title: string;
    }) => Promise<Item>;
    /**
     * 投稿を削除します。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    deleteItem: (itemId: string) => Promise<void>;
    /**
     * 投稿に「いいね！」を付けているかどうかを調べます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    checkIfLikedItem: (itemId: string) => Promise<void>;
    /**
     * 投稿に「いいね！」を付けます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    likeItem: (itemId: string) => Promise<void>;
    /**
     * 投稿への「いいね！」を取り消します。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    unlikeItem: (itemId: string) => Promise<void>;
    /**
     * 投稿をストックしているかどうかを調べます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    checkIfStockedItem: (itemId: string) => Promise<void>;
    /**
     * 投稿をストックします。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    stockItem: (itemId: string) => Promise<void>;
    /**
     * 投稿をストックから取り除きます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    unstockItem: (itemId: string) => Promise<void>;
    /**
     * 記事に付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param itemId 投稿ID
     * @return 絵文字リアクション
     */
    fetchItemReactions: (itemId: string) => Promise<Reaction[]>;
    /**
     * 記事に絵文字リアクションを付けます。
     * @param itemId 投稿ID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createItemReaction: (itemId: string, name: string) => Promise<Reaction>;
    /**
     * 記事から絵文字リアクションを削除します。
     * @param itemId 投稿ID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteItemReaction: (itemId: string, name: string) => Promise<Reaction>;
    /**
     * 投稿につけられた「いいね！」を作成日時の降順で返します。
     * @param itemId 投稿のID
     * @return いいね！エンティティを返します
     */
    fetchItemLikes: (itemId: string) => Promise<Like[]>;
    /**
     * 投稿をストックしているユーザ一覧を、ストックした日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchItemStockers: (itemId: string, page: string, perPage: string) => AsyncIterableIterator<User[]>;
    /**
     * 投稿に付けられたコメント一覧を投稿日時の降順で取得します。
     * @param itemId 投稿のID
     * @return コメント一覧
     */
    fetchItemComments: (itemId: string) => Promise<Comment[]>;
    /**
     * 投稿に対してコメントを投稿します。
     * @param itemId 投稿のID
     * @param body コメントの内容を表すMarkdown形式の文字列
     * @return 投稿したコメント
     */
    createItemComment: (itemId: string, body: string) => Promise<Comment[]>;
    /**
     * 投稿にタグを追加します。Qiita:Teamでのみ有効です。
     * @param itemId 投稿のID
     * @param name タグを特定するための一意な名前
     * @param versions (説明なし)
     */
    addItemTag: (itemId: string, name: string, versions: string[]) => Promise<Tagging>;
    /**
     * 投稿から指定されたタグを取り除きます。Qiita:Teamでのみ有効です。
     * @param itemId 投稿のID
     * @param tagId タギングのID
     * @return 空のオブジェクト
     */
    removeItemTag: (itemId: string, tagId: string) => Promise<void>;
    /**
     * ユーザが所属している全てのチームを、チーム作成日時の降順で返します。
     * @return チーム一覧
     */
    fetchTeams: () => Promise<Team[]>;
    /**
     * 招待中のメンバーの一覧を返します
     * @return 招待
     */
    fetchTeamInvitations: () => Promise<TeamInvitation>;
    /**
     * チームにメンバーを招待します
     * @return 招待
     */
    createTeamInvitations: () => Promise<TeamInvitation>;
    /**
     * 招待を取り消します
     * @return 空のオブジェクト
     */
    deleteTeamInvitation: () => Promise<void>;
    /**
     * アクセストークンに紐付いたユーザを返します。
     * @return 認証中のユーザ
     */
    fetchMe: () => Promise<AuthenticatedUser>;
    /**
     * 認証中のユーザの投稿の一覧を作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchMyItems: (page: string, perPage: string) => AsyncIterableIterator<Item[]>;
}
